import sys
import json
from pathlib import Path # if you haven't already done so
file = Path(__file__).resolve()
parent, root = file.parent, file.parents[1]
sys.path.append(str(root))

# Additionally remove the current file's directory from sys.path
try:
    sys.path.remove(str(parent))
except ValueError: # Already removed
    pass

from xsdata.formats.dataclass.context import XmlContext
from xsdata.formats.dataclass.parsers import XmlParser, JsonParser
from xsdata.formats.dataclass.serializers import JsonSerializer, XmlSerializer
from xsdata.formats.dataclass.serializers.config import SerializerConfig
from pathlib import PurePath
from generate4 import TriangulatedSetRepresentation
# from generated.energistics_org_energyml_data_commonv2 import Activity


def xml_to_json(filename: str):
    parser = XmlParser(context=XmlContext())
    tsr = parser.parse(filename, TriangulatedSetRepresentation)
    print(tsr)
    print("-----")
    serializer = JsonSerializer(context=XmlContext(), indent=2)
    json_instance = serializer.render(tsr)
    print(json_instance)
    return json_instance

def json_to_xml(string: str):
    parser = JsonParser(context=XmlContext())
    tsr = parser.from_string(string, TriangulatedSetRepresentation)
    print(tsr)
    print("######")
    serializer = XmlSerializer(context=XmlContext(), config=SerializerConfig(pretty_print=True))
    xml_instance = serializer.render(tsr)
    print(xml_instance)
    return xml_instance

def main(argv):

    # xml to json

    #filename = "TriangulatedSetRepresentation_17004506-f1db-4d34-8d66-efd6b4b15d73.xml"
    json_obj = xml_to_json(argv[0])

    outfilename = Path(argv[0]).stem

    with open(outfilename+'.json', 'w') as outfile:
        outfile.write(json_obj)

    xml_obj = json_to_xml(json_obj)

    with open(outfilename+'.out.xml', 'w') as outfile:
        outfile.write(xml_obj)        

if __name__ == "__main__":
    main(sys.argv[1:])


